function h = vline(x,in1,in2)
% function h = vline(x, linetype, label)
% 
% Draws a vertical line on the current axes at the location specified by 'x'. 
% 
% Original code was submitted by:
% By Brandon Kuczenski for Kensington Labs.
% 
% 8 November 2001

% This code has been modified from it's original version to support this file

for i=1:length(x)
    
    % Create Context Menu for the Line
    cmenu_line = uicontextmenu;
    item1 = uimenu(cmenu_line, 'Label', 'Delete', 'Callback', @DeleteFcn);
    item2 = uimenu(cmenu_line,'Label','Turn off text','Callback',@TextFcn);
    
    % Create Context Menu for the text
    cmenu_text = uicontextmenu;
    item1 = uimenu(cmenu_text, 'Label', 'Snap Text To Line', 'Callback', @SnapFcn);
    item2 = uimenu(cmenu_text,'Label','Justify Text');
    
    % Create a Sun Context Menu
    item_sub1 = uimenu(item2,'Label','Left','Callback',@JustifyFcn,'Checked','On');
    item_sub2 = uimenu(item2,'Label','Right','Callback',@JustifyFcn);
    item_sub3 = uimenu(item2,'Label','Center','Callback',@JustifyFcn);
    
    set(item_sub1,'UserData',[item_sub2 item_sub3]);
    set(item_sub2,'UserData',[item_sub1 item_sub3]);
    set(item_sub3,'UserData',[item_sub1 item_sub2]);
    % Create the lines with appropriate properties
    if ~iscell(in1)
        linetype = in1;  
    elseif i>length(in1)
        linetype=in1{end};
    else
        linetype=in1{i};
    end
    
    label = in2{i};
    g=ishold(gca);
    hold on
    xpos = x(i);
    y=get(gca,'ylim');
    h(i)=plot([xpos xpos],y,linetype,'UIContextMenu',cmenu_line);
    
    xx=get(gca,'xlim');
    xrange=xx(2)-xx(1);
    
    % Set text location to the middle of line
    ymid = mean(y);
    
    h_text(i) = text(xpos,ymid,label,'color',get(h(i),'color'),'UIContextMenu',cmenu_text,'UserData',1,'HorizontalAlignment','Left');
    set(h_text(i),'ButtonDownFcn',@DownFcn)
    set(h_text(i),'EraseMode','xor')
    set(h(i),'UserData',h_text(i))
    
    if g==0
        hold off
    end    
end